@@ -21,7 +21,7 @@
 #include "babl-internal.h"
 #include "babl-ref-pixels.h"
 
-#define BABL_TOLERANCE             0.000006
+#define BABL_TOLERANCE             0.000001
 #define BABL_MAX_COST_VALUE        2000000
 #define BABL_HARD_MAX_PATH_LENGTH  8
 #define BABL_MAX_NAME_LEN          1024
@@ -333,6 +333,11 @@ babl_fish_path (const Babl *source,
 
     get_conversion_path (&pc, (Babl *) source, 0, max_path_length ());
 
+    /* second attempt,. at path length + 1*/
+    if (babl->fish_path.conversion_list->count == 0 &&
+        max_path_length () + 1 <= BABL_HARD_MAX_PATH_LENGTH)
+      get_conversion_path (&pc, (Babl *) source, 0, max_path_length () + 1);
+
     babl_in_fish_path--;
     babl_free (pc.current_path);
   }
@@ -341,6 +346,29 @@ babl_fish_path (const Babl *source,
     {
       babl_free (babl);
       babl_mutex_unlock (babl_format_mutex);
+
+#ifndef BABL_UNSTABLE
+      if (debug_conversions)
+#endif
+      {
+        static int warnings = 0;
+
+        if (_babl_legal_error() <= 0.0000000001)
+            return NULL;
+
+        if (warnings++ == 0)
+          fprintf (stderr,
+"Missing fast-path babl conversion detected, Implementing missing babl fast paths\n"
+"accelerates GEGL, GIMP and other software using babl, warnings are printed on\n"
+"first occurance of formats used where a conversion has to be synthesized\n"
+"programmatically by babl based on format description\n"
+"\n");
+
+        fprintf (stderr, "*WARNING*: missing babl fast path(s) between formats \"%s\" and \"%s\"\n",
+           babl_get_name (source),
+           babl_get_name (destination));
+
+      }
       return NULL;
     }
 
