@@ -84,7 +84,6 @@ long     babl_fish_reference_process    (const Babl *babl,
 Babl   * babl_fish_reference            (const Babl     *source,
                                          const Babl     *destination);
 Babl   * babl_fish_simple               (BablConversion *conversion);
-void     babl_fish_stats                (FILE           *file);
 Babl   * babl_fish_path                 (const Babl     *source,
                                          const Babl     *destination);
 
@@ -144,7 +143,7 @@ real_babl_log (const char *file,
   va_list  varg;
 
   va_start (varg, fmt);
-  real_babl_log_va(file, line, function, fmt, varg);
+  real_babl_log_va (file, line, function, fmt, varg);
   va_end (varg);
 }
 
@@ -168,9 +167,9 @@ real_babl_log (const char *file,
 #define babl_log(...)                                       \
   real_babl_log(__FILE__, __LINE__, G_STRFUNC, __VA_ARGS__)
 
-#define babl_fatal(...) do{                         	    \
+#define babl_fatal(...) do{                                  \
   real_babl_log(__FILE__, __LINE__, G_STRFUNC, __VA_ARGS__); \
-  babl_die();}                                              \
+  babl_die();}                                               \
 while(0)
 
 #elif defined(BABL_GNUC_VARIADIC_MACROS)
@@ -270,7 +269,11 @@ babl_##klass (const char *name)                               \
                                                               \
   if (babl_hmpf_on_name_lookups)                              \
     {                                                         \
-      babl_log ("%s(\"%s\"): hmpf!", G_STRFUNC, name);        \
+      babl_log ("%s(\"%s\"): looking up", G_STRFUNC, name);   \
+    }                                                         \
+  if (!db)                                                    \
+    {                                                         \
+      babl_fatal ("%s(\"%s\"): you must call babl_init first", G_STRFUNC, name);  \
     }                                                         \
   babl = babl_db_exist_by_name (db, name);                    \
                                                               \
@@ -317,4 +320,9 @@ static inline double babl_parse_double (const char *str)
 }
 
 
+double _babl_legal_error (void);
+void babl_init_db (void);
+void babl_store_db (void);
+int _babl_max_path_len (void);
+
 #endif
