@@ -31,12 +31,20 @@ babl_list_init (void)
   return babl_list_init_with_size (BABL_LIST_INITIAL_SIZE);
 }
 
+static int
+babl_list_destroy (void *data)
+{
+  BablList *list = data;
+  babl_free (list->items);
+  return 0;
+}
+
 BablList *
 babl_list_init_with_size (int initial_size)
 {
   BablList *list = babl_calloc (sizeof (BablList), 1);
 
-  babl_assert (list);
+  babl_set_destructor (list, babl_list_destroy);
 
   if (initial_size == 0)
     initial_size = 1;
@@ -52,23 +60,6 @@ babl_list_init_with_size (int initial_size)
 }
 
 void
-babl_list_destroy (BablList *list)
-{
-    babl_assert (list);
-
-    babl_free (list->items);
-    babl_free (list);
-}
-
-int
-babl_list_size (BablList *list)
-{
-    babl_assert (list);
-
-    return list->count;
-}
-
-inline void
 babl_list_insert_last (BablList *list,
                        Babl     *item)
 {
@@ -88,7 +79,7 @@ babl_list_insert_last (BablList *list,
     list->items[list->count++] = item;
 }
 
-inline void
+void
 babl_list_remove_last (BablList *list)
 {
   babl_assert (list);
@@ -97,25 +88,7 @@ babl_list_remove_last (BablList *list)
   list->count--;
 }
 
-inline Babl *
-babl_list_get_first (BablList *list)
-{
-  babl_assert (list);
-  babl_assert (list->count > 0);
-
-  return (list->items[0]);
-}
-
-inline Babl *
-babl_list_get_last (BablList *list)
-{
-  babl_assert (list);
-  babl_assert (list->count > 0);
-
-  return (list->items[list->count - 1]);
-}
-
-inline void
+void
 babl_list_copy (BablList *from,
                 BablList *to)
 {
