@@ -23,6 +23,7 @@
 #define NEEDS_BABL_DB
 #include "babl-internal.h"
 #include "babl-db.h"
+#include "babl-ref-pixels.h"
 
 static const Babl *construct_double_format (const Babl *model);
 
@@ -98,7 +99,7 @@ babl_model_new (void *first_argument,
                 ...)
 {
   va_list        varg;
-  Babl          *babl;
+  Babl          *babl          = NULL;
   int            id            = 0;
   int            components    = 0;
   const char    *arg           = first_argument;
@@ -110,21 +111,32 @@ babl_model_new (void *first_argument,
 
   while (1)
     {
-      if (BABL_IS_BABL (arg))
+      /* first, we assume arguments to be strings */
+      if (!strcmp (arg, "id"))
         {
-          Babl *babl = (Babl *) arg;
+          id = va_arg (varg, int);
+        }
 
-          switch (babl->class_type)
+      else if (!strcmp (arg, "name"))
+        {
+          assigned_name = va_arg (varg, char *);
+        }
+
+      /* if we didn't point to a known string, we assume argument to be babl */
+      else if (BABL_IS_BABL (arg))
+        {
+          Babl *bablc = (Babl *) arg;
+
+          switch (bablc->class_type)
             {
               case BABL_COMPONENT:
-                component [components] = (BablComponent *) babl;
-                components++;
-
                 if (components >= BABL_MAX_COMPONENTS)
                   {
                     babl_log ("maximum number of components (%i) exceeded for %s",
-                              BABL_MAX_COMPONENTS, assigned_name);
+                              BABL_MAX_COMPONENTS,
+                              assigned_name ? assigned_name : "(unnamed)");
                   }
+                component [components++] = (BablComponent *) bablc;
                 break;
 
               case BABL_MODEL:
@@ -149,27 +161,18 @@ babl_model_new (void *first_argument,
               case BABL_FISH_PATH:
               case BABL_IMAGE:
               case BABL_EXTENSION:
-                babl_log ("%s unexpected", babl_class_name (babl->class_type));
+                babl_log ("%s unexpected", babl_class_name (bablc->class_type));
                 break;
 
               case BABL_SKY: /* shut up compiler */
                 break;
             }
         }
-      /* if we didn't point to a babl, we assume arguments to be strings */
-      else if (!strcmp (arg, "id"))
-        {
-          id = va_arg (varg, int);
-        }
-
-      else if (!strcmp (arg, "name"))
-        {
-          assigned_name = va_arg (varg, char *);
-        }
 
       else
         {
-          babl_fatal ("unhandled argument '%s' for babl_model '%s'", arg, assigned_name);
+          babl_fatal ("unhandled argument '%s' for babl_model '%s'",
+		      arg, assigned_name ? assigned_name : "(unnamed)");
         }
 
       arg = va_arg (varg, char *);
@@ -187,8 +190,7 @@ babl_model_new (void *first_argument,
   if (!components)
     {
       babl_log("no components specified for model '%s'", name);
-      babl_free(name);
-      return NULL;
+      goto out;
     }
 
   babl = babl_db_exist (db, id, name);
@@ -208,6 +210,7 @@ babl_model_new (void *first_argument,
                           "with different components!", name);
     }
 
+ out:
   babl_free (name);
 
   return babl;
@@ -216,24 +219,6 @@ babl_model_new (void *first_argument,
 
 #define TOLERANCE      0.001
 
-#define test_pixels    512
-
-static double *
-test_create (void)
-{
-  double *test;
-  int     i;
-
-  srandom (20050728);
-
-  test = babl_malloc (sizeof (double) * test_pixels * 4);
-
-  for (i = 0; i < test_pixels * 4; i++)
-    test [i] = ((double) random () / RAND_MAX) * 1.4 - 0.2;
-
-  return test;
-}
-
 static const Babl *reference_format (void)
 {
   static const Babl *self = NULL;
@@ -289,7 +274,6 @@ double
 babl_model_is_symmetric (const Babl *cbabl)
 {
   Babl *babl = (Babl*)cbabl;
-  double *test;
   void   *original;
   double *clipped;
   void   *destination;
@@ -301,7 +285,9 @@ babl_model_is_symmetric (const Babl *cbabl)
   Babl *fish_to;
   Babl *fish_from;
 
-  test      = test_create ();
+  const int test_pixels = babl_get_num_model_test_pixels ();
+  const double *test = babl_get_model_test_pixels ();
+
   ref_fmt   = reference_format ();
   fmt       = construct_double_format (babl);
   fish_to   = babl_fish_reference (ref_fmt, fmt);
@@ -360,7 +346,6 @@ babl_model_is_symmetric (const Babl *cbabl)
   babl_free (clipped);
   babl_free (destination);
   babl_free (transformed);
-  babl_free (test);
   return symmetric;
 }
 
